QDFT

Struct QDFT 

pub struct QDFT<T, F>
where T: Float + CastFrom<F>, F: Float + CastFrom<T> + CastFrom<f64>,
{ /* private fields */ }
Constant-Q Sliding Discrete Fourier Transform (QDFT).

Arguments

  • T - Time domain data type.
  • F - Frequency domain data type.

Both T and F must be f32 or f64 respectively.

Implementations

Source

impl<T, F> QDFT<T, F>
where T: Float + CastFrom<F>, F: Float + CastFrom<T> + CastFrom<f64>,

pub fn new( samplerate: f64, bandwidth: (f64, f64), resolution: f64, latency: f64, window: Option<(f64, f64)>, ) -> Self

Returns a new QDFT plan instance for the specified parameters.

Arguments
  • samplerate - Sample rate in hertz.
  • bandwidth - Lowest and highest frequency in hertz to be resolved.
  • resolution - Octave resolution, e.g. number of DFT bins per octave.
  • latency - Analysis latency adjustment between -1 and +1.
  • window - Cosine family window coeffs, e.g. (+0.5,-0.5) in case of hann window.
pub fn size(&self) -> usize

Returns the number of DFT bins derived from the bandwidth and resolution.

pub fn samplerate(&self) -> f64

Returns the sample rate in hertz.

pub fn bandwidth(&self) -> (f64, f64)

Returns the lowest and highest frequency in hertz to be resolved.

pub fn resolution(&self) -> f64

Returns the octave resolution, e.g. number of DFT bins per octave.

pub fn quality(&self) -> f64

Returns the quality factor derived from the resolution.

pub fn latency(&self) -> f64

Returns the analysis latency factor.

pub fn frequencies(&self) -> &[f64]

Returns frequency values in hertz of the individual DFT bins.

pub fn window(&self) -> Option<(f64, f64)>

Returns the cosine family window coeffs, e.g. (+0.5,-0.5) in case of hann window.

pub fn qdft_scalar(&mut self, sample: &T, dft: &mut [Complex<F>])

Estimate the DFT vector for the given sample.

pub fn iqdft_scalar(&mut self, dft: &[Complex<F>], sample: &mut T)

Synthesize the sample from the given DFT vector.

pub fn qdft_vector(&mut self, samples: &[T], dfts: &mut [Complex<F>])

Estimate the DFT matrix for the given sample array.

pub fn iqdft_vector(&mut self, dfts: &[Complex<F>], samples: &mut [T])

Synthesize the sample array from the given DFT matrix.

pub fn qdft(&mut self, samples: &[T], dfts: &mut [Complex<F>])

Estimate the DFT matrix for the given sample array. This is a shortcut for the function [qdft_vector].

pub fn iqdft(&mut self, dfts: &[Complex<F>], samples: &mut [T])

Synthesize the sample array from the given DFT matrix. This is a shortcut for the function [iqdft_vector].